@@ -7,7 +7,7 @@ from tasq_cli.utils import get_config_directory, get_config_file_path, get_crede
 KB = 1024
 MB = KB * 1024
 
-VERSION = '1.0.11'
+VERSION = '1.0.12'
 
 # ---
 # Logging
@@ -67,4 +67,4 @@ SECRET_KEY = creds['secret_key']
 # TODO
 ## pip distribution
 
-CDN_URL = 'https://cdn.tasq.ai/{object_name}' # TODO actual url
+CDN_URL = 'https://assets.tasq.ai/{object_name}'
